# The Lo-Fi Manifesto

## Preamble

The time has come to reject expensive consumer and prosumer software that hinders the extensibility of digital discourse and limits digital production literacy to programs and file formats that are destined for disruptive upgrades or obsolescence.

Digital scholars in the loosely defined fields of rhetoric and composition, computers and writing, and technical communication should create free and open source artifacts that are software- and device-independent. Discourse posted on the open Web can hardly be considered free if access requires costly software or particular devices.

Additionally, the literacies and language we develop through engaging in digital scholarship and knowledge-making should enable us to speak confidently, unambiguously, and critically with one another about the intricacies and methods of digital production.

And as teachers, we should actively work to provide students with sustainable, extensible production literacies through open, rhetorically grounded digital practices that emphasize the source in “free and open source.”

## Defining Lo-fi Technologies

Lo-fi production technologies are stable and free. They consist of and/or can retrograde to:

1. Plain text files (.txt, .xml, .htm, .css, .js, etc.)
2. Plain text editors (Notepad, TextEdit, pico/nano, vi, etc.)
3. Standardized, human-readable forms of open languages expressed in plain text (XML, XHTML, CSS, JavaScript, etc.)
4. Single-media files (image, audio, video) in open formats

Despite their humble, decades-old base technology (plain text), innovative uses of lo-fi technologies can be remarkably hi-fi, as in the case of AJAX (whose most famous application may be Google’s Gmail service).

## Lo-fi is LOFI

“Lo-fi” describes a preferred set of production technologies that digital producers should strive to command, but as an acronym, LOFI outlines four principles of digital production that are essential for the advancement, extension, and long-term preservation of digital discourse:

**Lossless:** Discourse presented through lo-fi production technologies neither degrades nor becomes trapped in the production itself. Text migrates and transforms from a single source (e.g., XML, or an application of XML) to any number of other devices and artifacts; images, video, and other media elements maintain their integrity as individual files that are orchestrated with one another at a reader’s moment of access, not at the producer’s moment of File > Import or File > Save.

**Open:** Lo-fi artifacts’ source code and media elements are available for inspection, revision, and extension outside the scope of any one piece of production software and any one producer. Openness includes and encourages end-user/reader customization and repurposing.

**Flexible:** Discourse artfully and rhetorically created with lo-fi production technologies can be experienced unobtrusively in multiple ways by different users equipped with a wide variety of conventional, mobile, and adaptive devices—all from a single artifact. No plugins, special downloads, or device-/reader-specific artifacts are required.

**In(ter)dependent:** Lo-fi production technologies direct orchestration (like a recipe), not composition (like a TV dinner), allowing users and their devices full control to render (or not) and perhaps repurpose the media elements that constitute a digital artifact.

## Manifesto

1. Software is a poor organizing principle for digital production.
2. Digital literacy should reach beyond the limitations of software.
3. Discourse should not be trapped by production technologies.
4. Accommodate and forgive the end user, not the producer.
5. If a hi-fi element is necessary, keep it dynamic and unobtrusive.
6. Insist on open standards and formats, and software that supports them.

----

Karl Stolley

“The Lo-Fi Manifesto.” Kairos: A Journal of Rhetoric, Technology, and Pedagogy 12(3). Available \url{http://kairos.technorhetoric.net/12.3/} (May 2008).

Sources: 

* \url{http://kairos.technorhetoric.net/12.3/topoi/stolley/}
* \url{https://github.com/karlstolley/lo-fi}

