# Art after failure

## an artistic manifesto from the city of Bangalore

### Two justifications

This piece has the purpose of providing two extensive justifications. First, it attempts to explain why we, as a collective, have spent a period of artistic research in Bangalore, India. Bangalore is in fact undoubtedly far from the main geographical area where our work is normally based (that is Europe and the so called Western world, for the most part). Secondly, it proposes to justify our presence in the context of contemporary artistic production. This text is a report of our trip and a manifesto of our practice, both of which will merge together to justify our place and role in the world.

While interrogating our own artistic production, we want to define its style and ethos within what we tentatively name the Post Fail. As in Post Internet, here "post" means many different things at the same time. First, our art orbits around the **after failure** moment of the teleological narratives of technological development, in regards to both their enthusiastic and pessimistic visions. We assume that, in the long run, both utopian and dystopian narratives will disappoint, leaving us with much more mundane and varied realities. For example, we have recently approached drones and unmanned vehicles of different kinds. In recent times, these technologies have become common use products, mostly sold as toys. But drones are also presented by advertisers and enthusiasts as one of the most relevant technologies of the near future, as we are now allegedly leading towards a world in which deliveries and civil surveillance, movie production and warfare, will all be carried with and thanks to drones. In this case, we prefer to focus not exactly on the promise itself, but on the present moment in which we can already imagine that what we are told (mostly by the sellers of those technologies) is unlikely to happen, and definitely not through a smooth and uniform process.

Secondly, Post Fail also signifies that our art should be understood as taking place after acknowledging the failure of many of the post-whatever theories of the last decades. Many of the discourses that have been trying to make sense of contemporary art through a post-whatever condition, that we should all allegedly be sharing, have been hiding many of the contradictions and complexities of the present moment, of the when and where of their formulation. We want to investigate the complexities of the present more than anything else, including our own involvement in the production of discourses about such notion of the present. We find it difficult not to consider that what we do happens in a specific time, and that even if we talk about the future or the past we always do it from a specific temporal, cultural and geographical context. Post Fail means, as it will be argued, acknowledging the temporality of enunciation and the bodies it solicits and involves.

Finally, Post Fail might mean, perhaps with a slightly ironical twist, that we, IOCOSE, live and work in a constant state of **postal failure**. Being dispersed over three different cities, and communicating through e-mail, shared documents, cloud storage and VOIP technologies, we have come to accept the failure of communication as part of our work process. A failure we are perfectly fine with and which we like to dwell in, but that we also need to address when understanding our own practice. Internet is not just part of our everyday lives; it is also the essential condition that makes IOCOSE possible. With no internet connection we would simply not exist. We are IOCOSE during Internet, not after it (we need to communicate between ourselves to make things happen) and not before it (we cannot work together without Internet connection). Our art originates from all the misunderstandings, slowness and interruptions that distant communication brings with it.

So, why Bangalore? Why does this city matter in the theorisation of the Post Fail? We want to argue that Bangalore is an excellent example to understand and experience the importance of living, thinking and being **after failure**. In Bangalore the present moments in which the promises about the future of the city are enunciated and narrated matter more than anything else. The present of Bangalore is determined, in its architectural and urbanistic developments and through the introduction of businesses in the area, by a specific vision of the future. From what we experienced, this idea of the future generates immediate contradictions and inequalities, and quite interestingly most of these developments are carried out in the name of the corporations that invest in information technologies. Internet businesses are not just part of the city of Bangalore, but are the engine that drives the city towards a promised future. As Nair (2005) put it in the title of his text, Bangalore offers the ‘promise of the metropolis’. We like to look at Bangalore as a perfect occasion to investigate the present of such promises of technological and economic development, and to remind ourselves that these promises matter, are made of glass and steel that happens now, they move people, money and internet cables around the world that we live today. Through the notion of Post Fail we intend to respond to all this.

### A city within a city

What made Bangalore interesting for us was not the city itself, but the other city that lies within the city of Bangalore. This city-within-a-city is known as the Electronic City, or E-city. The E-city has been developing since the early 1980s and flourished in the last two decades. It consists of three areas, called Phase 1, 2 and 3, denominations for the successive stages of expansion that the E-city has undergone so far. The E-city hosts buildings and offices of the most important IT companies of the world. Its main purpose is to provide a safe and separated place where IT companies would base their businesses while being far from the problems (traffic, smog, etc.) that Bangalore has.

If Bangalore, with the possible exception of its most luxurious areas, is poor, slow, dirty, old and noisy, the E-city is instead rich, fast, clean, new and silent. Bangalore is chaotic, while the E-city is restrained. The E-city and its surrounding area is where everyone, according to the billboards that surround Bangalore, wants to live. The E-city has in fact a strictly Western style of architecture, a style that is (gated and) branded as luxurious and ambitious. One of the neighbourhoods built around the E-city is called Melrose Place, and it is in fact constructed in a way that should mimic the houses of the famous television series of the same name.

If Bangalore is flat with compounds that extend beyond the records of the official mapping of the city, the E-city is presented as "elevated"; an elevation of the E-city that is created and constantly reminded in the advertisements of the real estate agencies. Living in a Californian-style gated community is a way of elevating yourself, as billboards remind us. The process of self-elevation is not only physical (living on a skyscraper) but also spiritual. It means being detached from the rest of the world. It brings to a successful living, as a famous advertisement campaign from clothing company Diesel epitomised many years ago.

Many other architectural interventions in the city replicate the semantic opposition between elevation and flatness. The buildings around the E-city, developed to host those who work there, search for the sky, or at least for a physical detachment from the ground. According to a urban legend that we have heard more than once while being there, while the E-city was still in an embryonic stage an important figure of the IT business confessed to the entourage of the mayor of Bangalore that the promiscuity with the locals was seriously undermining the fostering of the IT economy in the area. In fact, the man explicitly suggested building a flyover highway to connect the city centre with the new E-city, so that traffic to the business centre would be faster. More importantly, he said that you cannot pretend to be a global leader if, between the time you wake up and the time you are at work, you are reminded of the poverty of the people around you. The flyover was suggested as a solution for detaching once and for all the engineers of the IT businesses from the average citizens of Bangalore. The city administration started, immediately after this conversation, the construction of a flyover highway: a little-big architectonic monstrosity that crosses the entire city and works as a reminder of how the efficiency of production can combine with class discrimination.

The Bangalore *Elevated Tool Way*, also known as Hosur Road, is part of the more extended National Highway number 7. The tool way connects the area of Silk Board and the E-city and crosses good part of the city, by passing over it. The toll costs approximately 70 Indian rupees. Not much, but enough to take the less wealthy citizens out of it. In about ten minutes it lets you cross a path that would otherwise take more than an hour, because of the traffic and wrecked conditions of the streets. It extends for more than 10Km and it has been inaugurated in 2010, less than five years ago.

The elevated toll way is born out of a dream for smooth transportation deprived of unforeseen consequences. In a similar fashion, the companies of the E-city base their entire businesses on the possibility of communicating with the offices in California, Europe or Asia, through data transmission that must be altered by noise of any kind. It is easy to draw a comparison between the modalities of work of the E-city and the elevated toll way. In both cases contaminations, disturbances and unplanned alterations are unwanted. As the "global leaders" of the E-city keep their status uncontaminated throughout the day, so the work produced within the E-city has to be sent and received with no corruptions of any kind.

It is not a coincidence that the E-city has an extraordinary cleanness. The entrance to the office area is surrounded by a gate, and access is restricted to the workers and their family members. However, it is possible to see from the outside that around the offices and within the gated space there are plenty of green areas, with fountains and flat roads. None of these things can normally be found in the rest of the city (a part from the botanical gardens).

It is quite clear from a few visits that in Bangalore Internet still *matters*. Internet, and particularly information technology business, here generates an economy that is visible from the architecture and distribution in the city area of the various social classes. Internet changes the shape of the city of Bangalore. It also changes the dreams and expectations of the population. However, the dreams associated with the digital revolution of Bangalore have to do with the expectations of a clean, smooth, fluid Californian style of living, a possibility that can be achieved only through elevation and detachment (by moving on a highway, living on a skyscraper, working in a gated office and so on).

Indeed, the contradictions of Bangalore are not more or less profound than those one can also find in European societies, where the four of us are born and raised and are currently living. However, here in Bangalore these are immediately visible to our foreign eyes. One could just look at the configuration of the city to see how the presence of IT industries is shaping the metropolis. Most of the development of Bangalore is driven by the E-city. In Bangalore, Internet is not strictly speaking a new thing, but incessantly produces new highways, skyscrapers and enclosed communities.

### The problem with the new things

> Not to lie about the future is impossible and one can lie about it at will

*(Naum Gabo, quoted by Barbrook and Cameron, 1996)*

In the seminal essay ‘The Californian Ideology’, Barbrook and Cameron effectively pointed out how the development of an Internet economy is far from being a purely economic and technological shift. It is entwined with ideological statements that have been the basis for a new kind of liberalism, one that puts the individual, and a certain idea of personal freedom, at its centre.

Produced around a vision of the future, such ideology appears to be oriented towards a future collective condition in which anyone, from anywhere in the world, will be able to express herself thanks to online and digital technologies. However, as the authors argue, narratives about the future have a strong ideological force because they overlook the partiality of the speaker. By offering a prediction on what the future could be, they become persuasive strategies about what should be done at the present. They influence the political economy of the present. And in Bangalore (often defined to the outsiders as the Silicon Valley of India), a specific narrative of the future has been used to enforce a neo-liberal economy based on infrastructure investments.

The narrative of the future that is changing the city of Bangalore suggests, for example, that one should commute to the E-city by flying over the rest of the city, using a purposefully built tolled highway. We can compare this to similar arguments that have been proposed to drive and manipulate policy changes in the immediate present. If we think at the drones phenomenon, we are often told that because drones will soon deliver parcels to our flats their use must be liberalised now (possibly also allowing surveillance companies and urban police to deploy a soon-to-be-familiar technology in our cities). We are also told that in the future every movement of our body will be monitored and tracked to prevent health issues, therefore quantified-self technologies must be financed and marketed now, so as to allow the future to happen. Those who tell these stories tend to appear as neutral speakers, sometimes supported by supposedly scientific facts to prove their point (TED talks are an excellent example of this rhetoric in which data is that which allows a transparent view into the future). The apparent neutrality of these discourses on the future of technological progression encourages immediate changes; changes that are far from neutral and affect the lives of many.

Bangalore is a clear example of a future that happens in the present time, and with tangible effects. The linearity of technological, economic and social progress is presented by specific actors who often have specific interests. And the idea of a post-whatever works in a similar way. As theoretical gesture, the post-whatever tells us the story of a historical development along with that of an imaginary future towards which a certain number of people are heading. Any post-whatever, when used to delineate a linear historical narrative of cause-effect relations, imagines time as following a clear progressive path, from the past towards a future condition.

### The problem with the Post-Internet

Discourses around post-whatever of any kind need to be interpreted within a political critique. And since our role of artists we want to contextualise our presence and role in the context of contemporary artistic production in relation to another post-whatever, the Post-Internet discourse.

We can take as a starter the seminal text by Artie Vierkant ‘The Image Object Post-Internet’. Here Post-Internet art is defined as ‘a result of the contemporary moment: inherently informed by ubiquitous authorship, the development of attention as currency, the collapse of physical space in networked culture, and the infinite reproducibility and mutability of digital materials’ (2010: 3). In Vierkant’s text there seems to be a clear understanding of what the contemporary moment is. Internet is, in this context, taken for granted, considered as a given which has now permeated the lives of a generation. The idea of the author is to adapt our perception and artistic production towards this new condition which we are all allegedly sharing, blurring the separation between images and objects in a scenario in which the image of the artwork is in fact already the artwork.

Similarly, David Joselit, in *After Art*, presents what he considers to be the contemporary mode of production and fruition of images. This condition has, according to the author, changed the evaluation of art and artworks. His text starts by quoting in the first page a comment that Donald Rubell, an art collector, made to the New York Times. Rubell says that ‘people are now realizing that art is an international currency’ (quoted in Joselit 2013: 3). This over generic statement about what people are now doing is not critiqued by Joselit, but used instead as the rationale for proposing a new mode of doing art: ‘what results after the “era of art” is a new kind of power that art assembles through its heterogeneous formats’ (91).

According to Jesse Darling (and Nicholas Mirzoeff) instead, the *post* of Post-Internet indicates that art happens at ‘the crisis of’ the Internet, not as a successor to it. Also, Darling states that ‘every artist working today is a postinternet artist’ (Darling 2014).

Indeed, Post-Internet can also be interpreted differently. ‘Post’ can also mean, maybe more simply, ‘doing art after being online’, as proposed by Marisa Olson in the original formulation of the Post-Internet (Cornell 2006). Post-Internet can also be seen, more broadly, as also including the new forms taken by the artistic investigations started by the net art movement, which tend to avoid replicating similar narratives of historical progression, at the cost maybe of being less accepted by the art market (Quaranta 2015). What we want to stress is that the works of authors such as Vierkant, Joselit and Darling tend to generate universal narratives of temporal and technological progression. Most importantly, these authors mentioned above do not reflect on the plurality of things that Internet *does*, and instead they speculate on what Internet supposedly is. It should appear quite obvious, for example, that art is a currency mostly for people like David Rubell, quoted by Joselit, and probably also for some of his friends. For the rest of the world it simply is not. In other words, these stories about who and where we are now, and what we are all doing, these common sense visions of our engagement with art and media hide the fact that someone is saying these stories, and that the act of telling is embedded in a political, cultural, economic scenario which is far from being obvious, or given.

What we are arguing is that Post-Internet as a movement, as varied and complex as it is, might work for the context of art criticism (particularly in those cases when it is presented also for its theoretical limitations). What is most worrying, for us, is how theories on the Post-Internet appear to derive from a common-sense understanding of how the world is, how it works and how we live in it. Of course, the common-sense logic is helpful when trying to make things simple and accessible to our understanding. But, within these conditions, we are going to prefer the *misunderstandings*: the failures, the disappointments, the events that complicate our expectations on what Internet, technologies and human beings are doing, or could be doing.

For these reasons we are much more comfortable with less authoritative claims and less generalising perspectives. Bangalore shows that Internet is not a fact that we all share, and not in the same way. It generates different things, for different people, depending on where they live, what their social status is, and what sort of access to education they have.

### Being Post Fail: Art after failure

What does it mean then, to be Post Fail? We propose a sort of manifesto, which also works as guideline and summary:
Being Post Fail and doing art after failure means:

* To accept that the future is (always?) a story we tell ourselves in the present time, and a story that is formulated in specific moments and received via specific bodies that are located in history.
* To accept that these very visions of the future will somehow disappoint, be them apocalyptic or as enthusiastic discourses, because there is not one single direction we are going to – and probably we are not even going anywhere.
* To accept the ethical challenge of doing art while recognising the limitations of one’s own position in the world and in history, yet while still saying something about the other possibilities in which our own present might also be.
* To do art as if being DJs at a party, but DJs who are already feeling the hangover of that same party. These DJs-with-an-headache have the imperative to keep the music going: they have to take care somehow of the tension towards the collective joy of the party while knowing that, surely, everyone will leave and go in a separate direction at the very end. Doing art Post Fail means asking ourselves the question of what music is appropriate to play in such context, how to respect own one’s headache while giving an interesting (and possibly enjoyable) experience.

There are several examples of this attitude in our production. To mention a few, the *[NoTube Contest](http://iocose.org/works/notube.html)* series for instance offers an award to who manages to find the most valueless video on YouTube. It is about the incredible amount of useless videos published and saved on YouTube, it acknowledges that YouTube is also, and maybe mostly about those useless videos with zero views, and yet tries to take care of these same videos with no value, of respecting and re-evaluating them for what they are.

The *[In Times of Peace](http://iocose.org/works/in_times_of_peace.html)* series imagines the life of a drone in a fictional time when war and terror are over. The impossibility of imagining such life is a way of reflecting on the difficulty of envisioning a time of peace. Yet the project takes care of such imagining an impossible future by dignifying a lonely drone which at least tries to do something for itself (such as running a 100 meters race, or taking selfies).

The series *[A Contemporary Portrait of the Internet Artist](http://iocose.org/works/a_contemporary_portrait_of_the_internet_artist.html)* offers a glimpse on the multiple meanings of making art, nowadays, in the so-called age of the Internet. It also exposes the not so enthusiastic reality of what many artists do nowadays (such as crowd/outsourcing work, working at the boundaries of copyright infringement, exploiting or being exploited by other artists and companies, etc.). The series tries to imagine how such a complex network of relations that come to be associated with 'Internet art' could be represented in a portrait, still using those same numerous forms of production and consumption that online technologies allow.

The photographic series we created for Silicon Plateau 1, Elevated Bangalore, also reflects these approaches and acts as a proposal for an art after failure. The series is an evidently distorted reportage from the city of Bangalore. In the photos, one sees buildings, vehicles and constructions of different sorts (including the Elevated Highway) stretched towards the sky. It is the dream of an elevated Bangalore that we propose to take as literally as possible, by lengthening (or enlightening, as Microsoft Word's AutoCorrect is now suggesting?) even the most humble rickshaw of the Indian driver who might be dreaming of achieving, one day, the elevation so noticeably promoted by the billboards all over Bangalore.

Clearly the rhetoric of elevation used by the real estate business in Bangalore is nothing but democratic, instead it is another way of promoting division and unfairness. With Elevated Bangalore we are trying to join in the blatant artificiality of the promises of technological and social progress that many IT companies are now replicating in Bangalore. Promises that sound similar to those used to discuss and promote digital software such as Photoshop, used to alter these images, and often advertised as tools that have changed our ways of seeing the world. The dream of an elevated Bangalore might actually improve the lives of the citizens of the city. What matters now, for us, is how this tension towards elevation generates a sort of collective hallucination, a hallucination which is also tangible throughout the city. We believe that such hallucinations need to be addressed through a Post Fail approach, one that acknowledges and takes responsibility of the place and time of its intervention, accepts its limitations and yet, somehow, still tries to play the music.

#### List of references

Barbrook, R. and Cameron, A. (1996) 'The Californian Ideology'. The Hypermedia Research Centre, [http://www.hrc.wmin.ac.uk/hrc/theory/californianideo/index/t.4.html](http://www.hrc.wmin.ac.uk/hrc/theory/californianideo/index/t.4.html), [Last accessed 13/03/2015]

Cornell, L. (2006) 'Closing the gap between art and life online', Time Out New York,[http://www.timeout.com/newyork/art/net-results](http://www.timeout.com/newyork/art/net-results) [Last accessed 13/03/2015]

Darling, J. (2014) ‘Post Whatever: on Ethics, Historicity, & the #usermilitia’, Rhizome.org, [http://rhizome.org/editorial/2014/dec/16/post-whatever-ethics-historicity-usermilitia/](http://rhizome.org/editorial/2014/dec/16/post-whatever-ethics-historicity-usermilitia/)[Last accessed 13/03/2015]

Joselit, D. (2013) After Art, Princeton University Press

Nair, J. (2005) The Promise of the Metropolis: Bangalore's Twentieth Century, Oxford University Press

Quaranta, D. (2015) 'Situating Post Internet', in Media Art. Toward a New Definition of Art in the Age of Technology, ed. by Valentino Catricalà, Pistoia (Italy): Gli Ori

Vierkant, A. (2010) 'The Image Object Post-Internet', available at [artievierkant.com/writing.php](http://www.artievierkant.com/writing.php) [Last accessed 13/03/2015]

---

by [IOCOSE](http://www.iocose.org) (Ruffino P., Cremonesi M., Cuttica F., Prati D.), available online at this [URL](http://iocose.org/art-after-failure/index.html)

*Originally published in Ghidini, M. and Kelton, T. (2015), Silicon Plateau Vol-1, T.A.J. Residency and SKE Projects, Bangalore: India*
